<?php

namespace App\Controller;

use App\Entity\Choix;
use App\Form\ChoixType;
use App\Repository\ChoixRepository;
use Knp\Component\Pager\PaginatorInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

/**
 * @Route("/choix")
 */
class ChoixController extends AbstractController
{
    /**
     * @Route("/", name="choix_index", methods={"GET"})
     */
    public function index(ChoixRepository $choixRepository, Request $request, PaginatorInterface $paginator): Response
    {
        $donnees = $choixRepository->findAll();

        $choixes = $paginator->paginate(
            $donnees,
            $request->query->getInt('page', 1),
            10
        );

        return $this->render('choix/index.html.twig', [
            'choixes' => $choixes,
        ]);
    }

    /**
     * @Route("/new", name="choix_new", methods={"GET","POST"})
     */
    public function new(Request $request): Response
    {
        $choix = new Choix();
        $form = $this->createForm(ChoixType::class, $choix);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->persist($choix);
            $entityManager->flush();

            return $this->redirectToRoute('choix_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('choix/new.html.twig', [
            'choix' => $choix,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="choix_show", methods={"GET"})
     */
    public function show(Choix $choix): Response
    {
        return $this->render('choix/show.html.twig', [
            'choix' => $choix,
        ]);
    }

    /**
     * @Route("/{id}/edit", name="choix_edit", methods={"GET","POST"})
     */
    public function edit(Request $request, Choix $choix): Response
    {
        $form = $this->createForm(ChoixType::class, $choix);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $this->getDoctrine()->getManager()->flush();

            return $this->redirectToRoute('choix_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('choix/edit.html.twig', [
            'choix' => $choix,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="choix_delete", methods={"POST"})
     */
    public function delete(Request $request, Choix $choix): Response
    {
        if ($this->isCsrfTokenValid('delete'.$choix->getId(), $request->request->get('_token'))) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->remove($choix);
            $entityManager->flush();
        }

        return $this->redirectToRoute('choix_index', [], Response::HTTP_SEE_OTHER);
    }
}
