<?php

namespace App\Controller;

use App\Entity\Examen;
use App\Entity\Theme;
use App\Form\ExamenType;
use App\Repository\ExamenRepository;
use Knp\Component\Pager\PaginatorInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

/**
 * @Route("/examen")
 */
class ExamenController extends AbstractController
{
    /**
     * @Route("/", name="examen_index", methods={"GET"})
     */
    public function index(ExamenRepository $examenRepository, Request $request, PaginatorInterface $paginator): Response
    {
        $donnees = $examenRepository->findAll();

        $examenss = $paginator->paginate(
            $donnees,
            $request->query->getInt('page', 1),
            10
        );

        return $this->render('examen/index.html.twig', [
            'examens' => $examenss,
        ]);
    }

    /**
     * @Route("/new", name="examen_new", methods={"GET","POST"})
     */
    public function new(Request $request): Response
    {
        $examen = new Examen();
        $form = $this->createForm(ExamenType::class, $examen);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->persist($examen);
            $entityManager->flush();

            return $this->redirectToRoute('examen_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('examen/new.html.twig', [
            'examen' => $examen,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/theme/{id}", name="examen_theme", methods={"GET"})
     */
    public function showE(Theme $theme, ExamenRepository $examenRepository, PaginatorInterface $paginator, Request $request): Response
    {

        $examens=$examenRepository -> findBy([
            'theme' => $theme->getId()
        ]);
        $examens=$paginator->paginate(
            $examens,
            $request->query->getInt('page', 1),
            5
        );

        return $this->render('examen/index.html.twig', [
            'examens' => $examens
        ]);
    }

    /**
     * @Route("/{id}", name="examen_list", methods={"GET"})
     */
    public function show(Examen $examen): Response
    {
        return $this->render('examen/show.html.twig', [
            'examen' => $examen,
        ]);
    }


    /**
     * @Route("/{id}/edit", name="examen_edit", methods={"GET","POST"})
     */
    public function edit(Request $request, Examen $examen): Response
    {
        $form = $this->createForm(ExamenType::class, $examen);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $this->getDoctrine()->getManager()->flush();

            return $this->redirectToRoute('examen_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('examen/edit.html.twig', [
            'examen' => $examen,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="examen_delete", methods={"POST"})
     */
    public function delete(Request $request, Examen $examen): Response
    {
        if ($this->isCsrfTokenValid('delete'.$examen->getId(), $request->request->get('_token'))) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->remove($examen);
            $entityManager->flush();
        }

        return $this->redirectToRoute('examen_index', [], Response::HTTP_SEE_OTHER);
    }
}
