<?php

namespace App\Controller;

use App\Entity\Choix;
use App\Entity\Examen;
use App\Entity\Question;
use App\Form\QuestionType;
use App\Repository\ChoixRepository;
use Knp\Component\Pager\PaginatorInterface;
use App\Repository\QuestionRepository;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

/**
 * @Route("/question")
 */
class QuestionController extends AbstractController
{
    /**
     * @Route("/", name="question_index", methods={"GET"})
     */
    public function index(QuestionRepository $questionRepository, Request $request, PaginatorInterface $paginator): Response
    {
        $donnees = $questionRepository->findAll();

        $questions = $paginator->paginate(
            $donnees,
            $request->query->getInt('page', 1),
            10
        );

        return $this->render('question/index.html.twig', [
            'questions' => $questions,
        ]);
    }

    /**
     * @Route("/ajouter", name="question_ajouter", methods={"POST"})
     */
    public function ajouter(Request $request): Response
    {
        if ($request->request->get('exam')) {
        $entityManager = $this->getDoctrine()->getManager();
        $count = 1;
        $examen = $request->request->get('exam');
        $questionPriorite=$entityManager->getRepository(Question::class)->findLast($examen);

        $question = new Question();
        $exam=$entityManager->getRepository(Examen::class)->find($request->request->get('exam'));
        $question->setExamen($exam)
        ->setExplication($request->request->get('explication'));
        if ($questionPriorite == null) {
            $question->setPriorite(1);
        }
        else{
            $question->setPriorite($questionPriorite + 1);
        }

        //upload image question
        if ($request->files->get("img")) {
            
            $fileFolder = __DIR__ . '/../../public/uploads/';

            $image = $request->files->get("img");
           
            $image_name = pathinfo($image->getClientOriginalName(), PATHINFO_FILENAME);

            $newImageName = $image_name . '-' . uniqid() . '.' . $image->guessExtension();

            $image->move($fileFolder, $newImageName);

            $question->setImage($newImageName);
            
        }

        $question->setLibelle($request->request->get('question'));
        $entityManager->persist($question);
        

        for ($i=1; $i < 5; $i++) { 
            $choix = new Choix();
            $choix->setQuestion($question)
            ->setExplication($request->request->get('explication'.$i))
            ->setLibelle($request->request->get('rep'.$i));
            if ($request->request->get('true'.$i))  $choix->setVraiFaux(1);
            else $choix->setVraiFaux(0);
            //upload image réponse
            if ($request->files->get('img'.$i)) {
                $fileFolder = __DIR__ . '/../../public/uploads/';
                $image = $request->files->get('img'.$i);
                $image_name = pathinfo($image->getClientOriginalName(), PATHINFO_FILENAME);
                $newImageName = $image_name . '-' . uniqid() . '.' . $image->guessExtension();
                $image->move($fileFolder, $newImageName);
                $choix->setImage($newImageName);
            }
            
            $entityManager->persist($choix);
        }
            $entityManager->flush();
        return $this->redirectToRoute('examen_index', [], Response::HTTP_SEE_OTHER);
    }
    }
    /**
     * @Route("/new", name="question_new", methods={"GET","POST"})
     */
    public function new(Request $request): Response
    {
        $question = new Question();
        $form = $this->createForm(QuestionType::class, $question);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->persist($question);
            $entityManager->flush();

            return $this->redirectToRoute('question_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('question/new.html.twig', [
            'question' => $question,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="question_show", methods={"GET"})
     */
    public function show(Question $question): Response
    {
        return $this->render('question/show.html.twig', [
            'question' => $question,
        ]);
    }

    /**
     * @Route("/{id}/edit", name="question_edit", methods={"GET","POST"})
     */
    public function modifier(Request $request, Question $question, ChoixRepository $cr): Response
    {
            if ($request->request->get('question')) {
                //dd($request->request);
            $entityManager = $this->getDoctrine()->getManager();   
            $question->setLibelle($request->request->get('question'))
            ->setExplication($request->request->get('questionexplication'));

            //upload image
            if ($request->files->get("img")) {
            
            $fileFolder = __DIR__ . '/../../public/uploads/';

            $image = $request->files->get("img");
           
            $image_name = pathinfo($image->getClientOriginalName(), PATHINFO_FILENAME);

            $newImageName = $image_name . '-' . uniqid() . '.' . $image->guessExtension();

            $image->move($fileFolder, $newImageName);

            $question->setImage($newImageName);
            
        }
            
            for ($i=1; $i <= 4; $i++) {
                $choix = $cr->find($request->request->get('nr'.$i));
                $choix
                ->setLibelle($request->request->get('rep'.$i))
                ->setExplication($request->request->get('exprep'.$i));
                if ($request->files->get('img'.$i)) {
                    $fileFolder = __DIR__ . '/../../public/uploads/';
                    $image = $request->files->get('img'.$i);
                    $image_name = pathinfo($image->getClientOriginalName(), PATHINFO_FILENAME);
                    $newImageName = $image_name . '-' . uniqid() . '.' . $image->guessExtension();
                    $image->move($fileFolder, $newImageName);
                    $choix->setImage($newImageName);
                }
                if ($request->request->get('true'.$i))  $choix->setVraiFaux(1);
                else $choix->setVraiFaux(0);
            }
                
                $entityManager->flush();

            return $this->redirectToRoute('question_edit', ['id'=>$question->getId()], Response::HTTP_SEE_OTHER);
    
        }
        
        if($request->request->get('error')) $error = $request->request->get('error'); else $error=null;
        return $this->render('question/edit.html.twig', [
            'question'=>$question,
            'error'=> $error,
        ]);

        
    return $this->render('question/edit.html.twig', [
        'question'=>$question
    ]);
    }

    /**
     * @Route("/{id}", name="question_delete", methods={"POST"})
     */
    public function delete(Request $request, Question $question): Response
    {
        if ($this->isCsrfTokenValid('delete'.$question->getId(), $request->request->get('_token'))) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->remove($question);
            $entityManager->flush();
        }

        return $this->redirectToRoute('question_index', [], Response::HTTP_SEE_OTHER);
    }

    /**
     * @Route("/ex/{id}", name="form_add", methods={"GET"})
     */
    public function formAjoutQuestion(Examen $exam): Response
    {
        return $this->render('question/add_question.html.twig', [
            'examen' => $exam 
        ]);
    }

    /**
     * @Route("/list/{id}", name="list_questions", methods={"GET"})
     */
    public function listQuestion(Examen $exam, Request $request,QuestionRepository $questionRepository, PaginatorInterface $paginator): Response
    {   
        $questions=$questionRepository -> findBy([
            'examen' => $exam->getId() 
        ]);
        $questions=$paginator->paginate(
            $questions,
            $request->query->getInt('page', 1),
            10
        );
        
        return $this->render('question/index.html.twig', [
            'questions' => $questions
        ]);
    }

    /**
     * @Route("/upload", name="upload_img", methods={"GET"})
     */
    public function upload_img(Examen $question): Response
    {
        return $this->render('question/upload.html.twig', [
            'question' => $question 
        ]);
    }
}
