<?php

namespace App\Controller;

use App\Entity\UserTheme;
use App\Form\UserThemeType;
use App\Repository\UserThemeRepository;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

/**
 * @Route("/user/theme")
 */
class UserThemeController extends AbstractController
{
    /**
     * @Route("/", name="user_theme_index", methods={"GET"})
     */
    public function index(UserThemeRepository $userThemeRepository): Response
    {
        return $this->render('user_theme/index.html.twig', [
            'user_themes' => $userThemeRepository->findAll(),
        ]);
    }

    /**
     * @Route("/new", name="user_theme_new", methods={"GET","POST"})
     */
    public function new(Request $request): Response
    {
        $userTheme = new UserTheme();
        $form = $this->createForm(UserThemeType::class, $userTheme);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->persist($userTheme);
            $entityManager->flush();

            return $this->redirectToRoute('user_theme_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('user_theme/new.html.twig', [
            'user_theme' => $userTheme,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="user_theme_show", methods={"GET"})
     */
    public function show(UserTheme $userTheme): Response
    {
        return $this->render('user_theme/show.html.twig', [
            'user_theme' => $userTheme,
        ]);
    }

    /**
     * @Route("/{id}/edit", name="user_theme_edit", methods={"GET","POST"})
     */
    public function edit(Request $request, UserTheme $userTheme): Response
    {
        $form = $this->createForm(UserThemeType::class, $userTheme);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $this->getDoctrine()->getManager()->flush();

            return $this->redirectToRoute('user_theme_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('user_theme/edit.html.twig', [
            'user_theme' => $userTheme,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="user_theme_delete", methods={"POST"})
     */
    public function delete(Request $request, UserTheme $userTheme): Response
    {
        if ($this->isCsrfTokenValid('delete'.$userTheme->getId(), $request->request->get('_token'))) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->remove($userTheme);
            $entityManager->flush();
        }

        return $this->redirectToRoute('user_theme_index', [], Response::HTTP_SEE_OTHER);
    }
}
