<?php

namespace App\Entity;

use App\Repository\ExamenRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

/**
 * @ORM\Entity(repositoryClass=ExamenRepository::class)
 */
class Examen
{
    /**
     * @ORM\Id
     * @ORM\GeneratedValue
     * @ORM\Column(type="integer")
     */
    private $id;

    /**
     * @ORM\Column(type="string", length=255)
     */
    private $libelle;

    /**
     * @ORM\Column(type="string", length=255)
     */
    private $description;

    /**
     * @ORM\ManyToOne(targetEntity=Theme::class, inversedBy="examens")
     */
    private $theme;

    /**
     * @ORM\OneToMany(targetEntity=Question::class, mappedBy="examen")
     */
    private $questions;

    /**
     * @ORM\OneToMany(targetEntity=UserExam::class, mappedBy="examen")
     */
    private $userExams;

    public function __construct()
    {
        $this->questions = new ArrayCollection();
        $this->userExams = new ArrayCollection();
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getLibelle(): ?string
    {
        return $this->libelle;
    }

    public function setLibelle(string $libelle): self
    {
        $this->libelle = $libelle;

        return $this;
    }

    public function getDescription(): ?string
    {
        return $this->description;
    }

    public function setDescription(string $description): self
    {
        $this->description = $description;

        return $this;
    }

    public function getTheme(): ?theme
    {
        return $this->theme;
    }

    public function setTheme(?theme $theme): self
    {
        $this->theme = $theme;

        return $this;
    }

    /**
     * @return Collection|Question[]
     */
    public function getQuestions(): Collection
    {
        return $this->questions;
    }

    public function addQuestion(Question $question): self
    {
        if (!$this->questions->contains($question)) {
            $this->questions[] = $question;
            $question->setExamen($this);
        }

        return $this;
    }

    public function removeQuestion(Question $question): self
    {
        if ($this->questions->removeElement($question)) {
            // set the owning side to null (unless already changed)
            if ($question->getExamen() === $this) {
                $question->setExamen(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|UserExam[]
     */
    public function getUserExams(): Collection
    {
        return $this->userExams;
    }

    public function addUserExam(UserExam $userExam): self
    {
        if (!$this->userExams->contains($userExam)) {
            $this->userExams[] = $userExam;
            $userExam->setExamen($this);
        }

        return $this;
    }

    public function removeUserExam(UserExam $userExam): self
    {
        if ($this->userExams->removeElement($userExam)) {
            // set the owning side to null (unless already changed)
            if ($userExam->getExamen() === $this) {
                $userExam->setExamen(null);
            }
        }

        return $this;
    }
}
