<?php

namespace App\Entity;

use App\Repository\ThemeRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

/**
 * @ORM\Entity(repositoryClass=ThemeRepository::class)
 */
class Theme
{
    /**
     * @ORM\Id
     * @ORM\GeneratedValue
     * @ORM\Column(type="integer")
     */
    private $id;

    /**
     * @ORM\Column(type="string", length=50)
     */
    private $libelle;

    /**
     * @ORM\Column(type="string", length=255)
     */
    private $description;

    /**
     * @ORM\Column(type="integer")
     */
    private $nbrQuestions;

    /**
     * @ORM\Column(type="integer")
     */
    private $tauxValidation;

    /**
     * @ORM\Column(type="integer")
     */
    private $dureeExamen;

    /**
     * @ORM\OneToOne(targetEntity=Image::class, cascade={"persist", "remove"})
     */
    private $image;

    /**
     * @ORM\OneToMany(targetEntity=Examen::class, mappedBy="theme", cascade={"remove"})
     */
    private $examens;

    /**
     * @ORM\OneToMany(targetEntity=UserTheme::class, mappedBy="theme")
     */
    private $userThemes;

    public function __construct()
    {
        $this->examens = new ArrayCollection();
        $this->userThemes = new ArrayCollection();
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getLibelle(): ?string
    {
        return $this->libelle;
    }

    public function setLibelle(string $libelle): self
    {
        $this->libelle = $libelle;

        return $this;
    }

    public function getDescription(): ?string
    {
        return $this->description;
    }

    public function setDescription(string $description): self
    {
        $this->description = $description;

        return $this;
    }

    public function getNbrQuestions(): ?int
    {
        return $this->nbrQuestions;
    }

    public function setNbrQuestions(int $nbrQuestions): self
    {
        $this->nbrQuestions = $nbrQuestions;

        return $this;
    }

    public function getTauxValidation(): ?int
    {
        return $this->tauxValidation;
    }

    public function setTauxValidation(int $tauxValidation): self
    {
        $this->tauxValidation = $tauxValidation;

        return $this;
    }

    public function getDureeExamen(): ?int
    {
        return $this->dureeExamen;
    }

    public function setDureeExamen(int $dureeExamen): self
    {
        $this->dureeExamen = $dureeExamen;

        return $this;
    }

    public function getImage(): ?image
    {
        return $this->image;
    }

    public function setImage(?image $image): self
    {
        $this->image = $image;

        return $this;
    }

    /**
     * @return Collection|Examen[]
     */
    public function getExamens(): Collection
    {
        return $this->examens;
    }

    public function addExamen(Examen $examen): self
    {
        if (!$this->examens->contains($examen)) {
            $this->examens[] = $examen;
            $examen->setTheme($this);
        }

        return $this;
    }

    public function removeExamen(Examen $examen): self
    {
        if ($this->examens->removeElement($examen)) {
            // set the owning side to null (unless already changed)
            if ($examen->getTheme() === $this) {
                $examen->setTheme(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|UserTheme[]
     */
    public function getUserThemes(): Collection
    {
        return $this->userThemes;
    }

    public function addUserTheme(UserTheme $userTheme): self
    {
        if (!$this->userThemes->contains($userTheme)) {
            $this->userThemes[] = $userTheme;
            $userTheme->setTheme($this);
        }

        return $this;
    }

    public function removeUserTheme(UserTheme $userTheme): self
    {
        if ($this->userThemes->removeElement($userTheme)) {
            // set the owning side to null (unless already changed)
            if ($userTheme->getTheme() === $this) {
                $userTheme->setTheme(null);
            }
        }

        return $this;
    }
}
