<?php

namespace App\Entity;

use App\Repository\UserRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Bridge\Doctrine\Validator\Constraints\UniqueEntity;
use Symfony\Component\Security\Core\User\UserInterface;

/**
 * @ORM\Entity(repositoryClass=UserRepository::class)
 * @UniqueEntity(fields={"email"}, message="There is already an account with this email")
 */
class User implements UserInterface
{
    /**
     * @ORM\Id
     * @ORM\GeneratedValue
     * @ORM\Column(type="integer")
     */
    private $id;

    /**
     * @ORM\Column(type="string", length=180, unique=true)
     */
    private $email;

    /**
     * @ORM\Column(type="json")
     */
    private $roles = [];

    /**
     * @var string The hashed password
     * @ORM\Column(type="string")
     */
    private $password;

    /**
     * @ORM\Column(type="string", length=50)
     */
    private $nom;

    /**
     * @ORM\Column(type="string", length=50)
     */
    private $prenom;

    /**
     * @ORM\Column(type="date")
     */
    private $dateNaissance;

    /**
     * @ORM\OneToMany(targetEntity=UserTheme::class, mappedBy="user")
     */
    private $userThemes;

    /**
     * @ORM\OneToMany(targetEntity=UserExam::class, mappedBy="user")
     */
    private $userExams;

    public function __construct()
    {
        $this->userThemes = new ArrayCollection();
        $this->userExams = new ArrayCollection();
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getEmail(): ?string
    {
        return $this->email;
    }

    public function setEmail(string $email): self
    {
        $this->email = $email;

        return $this;
    }

    /**
     * A visual identifier that represents this user.
     *
     * @see UserInterface
     */
    public function getUsername(): string
    {
        return (string) $this->email;
    }

    /**
     * @see UserInterface
     */
    public function getRoles(): array
    {
        $roles = $this->roles;
        // guarantee every user at least has ROLE_USER
        $roles[] = 'ROLE_USER';

        return array_unique($roles);
    }

    public function setRoles(array $roles): self
    {
        $this->roles = $roles;

        return $this;
    }

    /**
     * @see UserInterface
     */
    public function getPassword(): string
    {
        return $this->password;
    }

    public function setPassword(string $password): self
    {
        $this->password = $password;

        return $this;
    }

    /**
     * Returning a salt is only needed, if you are not using a modern
     * hashing algorithm (e.g. bcrypt or sodium) in your security.yaml.
     *
     * @see UserInterface
     */
    public function getSalt(): ?string
    {
        return null;
    }

    /**
     * @see UserInterface
     */
    public function eraseCredentials()
    {
        // If you store any temporary, sensitive data on the user, clear it here
        // $this->plainPassword = null;
    }

    public function getNom(): ?string
    {
        return $this->nom;
    }

    public function setNom(string $nom): self
    {
        $this->nom = $nom;

        return $this;
    }

    public function getPrenom(): ?string
    {
        return $this->prenom;
    }

    public function setPrenom(string $prenom): self
    {
        $this->prenom = $prenom;

        return $this;
    }

    public function getDateNaissance(): ?\DateTimeInterface
    {
        return $this->dateNaissance;
    }

    public function setDateNaissance(\DateTimeInterface $dateNaissance): self
    {
        $this->dateNaissance = $dateNaissance;

        return $this;
    }

    /**
     * @return Collection|UserTheme[]
     */
    public function getUserThemes(): Collection
    {
        return $this->userThemes;
    }

    public function addUserTheme(UserTheme $userTheme): self
    {
        if (!$this->userThemes->contains($userTheme)) {
            $this->userThemes[] = $userTheme;
            $userTheme->setUser($this);
        }

        return $this;
    }

    public function removeUserTheme(UserTheme $userTheme): self
    {
        if ($this->userThemes->removeElement($userTheme)) {
            // set the owning side to null (unless already changed)
            if ($userTheme->getUser() === $this) {
                $userTheme->setUser(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|UserExam[]
     */
    public function getUserExams(): Collection
    {
        return $this->userExams;
    }

    public function addUserExam(UserExam $userExam): self
    {
        if (!$this->userExams->contains($userExam)) {
            $this->userExams[] = $userExam;
            $userExam->setUser($this);
        }

        return $this;
    }

    public function removeUserExam(UserExam $userExam): self
    {
        if ($this->userExams->removeElement($userExam)) {
            // set the owning side to null (unless already changed)
            if ($userExam->getUser() === $this) {
                $userExam->setUser(null);
            }
        }

        return $this;
    }
}
